<?php

use Faker\Generator as Faker;
use Illuminate\Support\Str;
use Myriad\Authentication\Models\AccessToken;
use Myriad\Authentication\Models\User;
use Myriad\Authentication\Models\UserEmail;
use Myriad\Authentication\Models\UserPhone;
use Myriad\Installations\Models\Installation;

/*
|--------------------------------------------------------------------------
| Model Factories
|--------------------------------------------------------------------------
|
| Here you may define all of your model factories. Model factories give
| you a convenient way to create models for testing and seeding your
| database. Just tell the factory how a default model should look.
|
 */

$factory->define(User::class, function (Faker $faker) {
  return [
    'first_name' => $faker->firstName,
    'last_name' => $faker->lastName,
    'password' => bcrypt($faker->password),
    'last_login' => $faker->date(),
    'remember_token' => str_random(10),
  ];
});

$factory->define(Installation::class, function(Faker $faker) {
  return [
    'uuid' => $faker->uuid,
    'app_name' => '1.23-' . $faker->randomElement(['ios', 'android', 'web']),
    'app_version' => '1.23'
  ];
});

$factory->define(AccessToken::class, function(Faker $faker) {
  return [
    'token' => Str::random(),
    'type' => $faker->randomElement(['auth', 'password_reset', 'claim']),
    'expires_at' => now()->addSeconds($faker->numberBetween(-60, 3600))
  ];
});

$factory->define(UserPhone::class, function(Faker $faker) {
  return [
    'phone' => $faker->phoneNumber,
    'type' => $faker->randomElement([
      UserPhone::TYPE_WORK,
      UserPhone::TYPE_CELL,
      UserPhone::TYPE_HOME,
    ]),
    'primary' => $faker->boolean(),
    'verified' => $faker->boolean(),
  ];
});

$factory->define(UserEmail::class, function(Faker $faker) {
  return [
    'email' => $faker->email,
    'type' => $faker->randomElement([
      UserEmail::TYPE_WORK,
      UserEmail::TYPE_HOME,
    ]),
    'primary' => $faker->boolean(),
    'verified' => $faker->boolean(),
  ];
});
