<?php

use Illuminate\Events\Dispatcher;
use Myriad\Authentication\Lib\Providers\EloquentUserProvider;
use Myriad\Authentication\Models\User;
use Myriad\Authentication\Lib\Repositories\EloquentAccessTokenRepository;
use Illuminate\Hashing\BcryptHasher;
use Illuminate\Config\Repository;
use Myriad\Authentication\Http\Requests\SendVerificationCodeRequest;
use Myriad\Authentication\Http\Requests\VerifyVerificationCodeRequest;
use Myriad\Authentication\Http\Requests\UserRegistrationRequest;

trait BootstrapsKernel {
  protected static $app;
  protected static $kernel;

  public static function bootstrapKernel($settings, $kernelType) {
    require_once __DIR__."/../../bootstrap/autoload.php";
    self::$app = require __DIR__."/../../bootstrap/app.php";

    // bind user provider
    self::$app->bind('Illuminate\Contracts\Auth\UserProvider', function($app) {
      $hasher = new BcryptHasher();
      $tokenRepo = new EloquentAccessTokenRepository();
      return new EloquentUserProvider($hasher, $tokenRepo, User::class);
    });

    self::$app->bind(SendVerificationCodeRequest::class, function($app) {
      return SendVerificationCodeRequest::createFromBase($app['request']);
    });

    self::$app->bind(VerifyVerificationCodeRequest::class, function($app) {
      return VerifyVerificationCodeRequest::createFromBase($app['request']);
    });

    self::$app->bind(UserRegistrationRequest::class, function($app) {
      return UserRegistrationRequest::createFromBase($app['request']);
    });

    self::$kernel = self::$app->make($kernelType);
    self::$kernel->bootstrap();

    $router = self::$app->make('Illuminate\Routing\Router');
    require __DIR__."/../../src/routes.php";

    $dispatcher = self::$app->make(Dispatcher::class);
  }
}
