<?php

namespace spec\Myriad\Authentication\Lib\Jobs;

use Carbon\Carbon;
use Illuminate\Contracts\Auth\UserProvider;
use Illuminate\Contracts\Bus\Dispatcher;
use Illuminate\Contracts\Validation\Factory;
use Illuminate\Contracts\Validation\Validator;
use Myriad\Authentication\Lib\Jobs\CreateUserInstallationAccessToken;
use Myriad\Authentication\Lib\Jobs\LoginWithEmailFromInstallation;
use Myriad\Authentication\Models\User;
use Myriad\Installations\InstallationManager;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;

class LoginWithEmailFromInstallationSpec extends ObjectBehavior
{
    function let()
    {
        $this->beConstructedWith([
            'email' => 'somebody@example.com',
            'password' => 'password12345',
            'installation_uuid' => "0126608a29fb436a85fe96029b9a3d17",
        ]);
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(LoginWithEmailFromInstallation::class);
    }

    function it_should_log_users_in_with_email_and_password(
        InstallationManager $manager,
        Factory $validationFactory,
        Validator $validator,
        UserProvider $provider,
        User $user,
        Dispatcher $dispatcher,
        Carbon $expiresAt
    ) {
        $uuid = "012a29930e614f22b9a482e0c56c55cb";
        $manager->getUuidFromRequest()->willReturn($uuid);
        $validationFactory->make(Argument::any(), Argument::type('array'))->willReturn($validator);
        $validator->fails()->willReturn(false);

        $provider->retrieveByCredentials(Argument::type('array'))->willReturn($user);
        $user->getAuthIdentifier()->willReturn(1);

        $accessToken = (object) ['uuid' => $uuid, 'expires_at' => $expiresAt];
        $expiresAt->toIso8601String()->willReturn("2016-05-06T20:32:18.883Z");
        $dispatcher->dispatchNow(Argument::type(CreateUserInstallationAccessToken::class))->willReturn($accessToken);

        $result = $this->handle($manager, $validationFactory, $provider, $dispatcher);

        $result->shouldHaveKey('access_token');
        $result->shouldHaveKey('expires_at');
    }

}
