<?php

namespace Myriad\Authentication\Models;

use Exception;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class VerificationCode extends Model
{
    use SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'contact',
        'code',
        'attempts',
        'data',
        'verification_strategy_type',
        'expires_at',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'contact',
        'code',
        'attempts',
        'data',
        'verification_strategy_type',
    ];

    /**
     * The attributes that should be mutated to dates.
     *
     * @var array
     */
    protected $dates = ['expires_at'];

    /**
     * Attempt to match this Verification Code's code with the code passed.
     * Calling this method increments the Verification Code's attempt count by 1.
     *
     * @param  string  $code
     * @return boolean
     */
    public function attemptToMatch($code)
    {
        $this->attempts += 1;
        $this->save();

        return $this->matches($code);
    }

    /**
     * Perform the verification strategy for this verification code.
     *
     * @param  string  $code
     * @return void
     */
    public function performVerificationStrategy($code)
    {
        if (!$this->matches($code)) {
            throw new Exception('Invalid code!');
        }

        $strategy = $this->getStrategy();
        // todo: don't pass attributes?
        return $strategy->performVerificationStrategy($code, $this->attributes);
    }

    private function matches($code)
    {
        return $code === $this->attributes['code'];
    }

    private function getStrategy()
    {
        return app($this->verification_strategy_type);
    }

}

